@@ -559,7 +559,9 @@ class BackendService(PolicyKitService):
         if not os.path.isfile(oldfile):
             raise UnsupportedException('Cannot find %s script' % oldfile)
 
-        print 'Updating %s...' % oldfile
+        logging.info('Updating %s...', oldfile)
+        logging.info('- receiver_values: %r', receiver_values)
+        logging.info('- remote_values: %r', remote_values)
 
         output = file(newfile, 'w')
         for line in file(oldfile, 'r'):
@@ -567,18 +569,20 @@ class BackendService(PolicyKitService):
             # Identify directives starting with REMOTE_ and replacing their values with ours.
             # Remove entry from the dict on match, so we know what was written.
             match = self.__re_remote_directive.match(line)
-            value = match and remote_values.pop(match.group(1), None) or None
+            value = match and remote_values.pop(match.group(1), None)
 
             if value is not None:
+                logging.info('- writing %s"%s"', match.group(0), value)
                 print >> output, ('%s"%s"' % (match.group(0), value))
                 continue
 
             # Identify directives starting with RECEIVER_ and replacing their values with ours.
             # Remove entry from the dict on match, so we know what was written.
             match = self.__re_receiver_directive.match(line)
-            value = match and receiver_values.pop(match.group(1), None) or None
+            value = match and receiver_values.pop(match.group(1), None)
 
             if value is not None:
+                logging.info('- writing %s"%s"', match.group(0), value)
                 print >> output, ('%s"%s"' % (match.group(0), value))
                 continue
 
@@ -698,10 +702,8 @@ class BackendService(PolicyKitService):
         '''Write include statement to central lircd.conf file.'''
 
         # read central lirc configuration file file:
-        lircd_config = os.path.join(config.LIRC_CONFDIR, 'lircd.conf')
-
         try:
-            contents = open(lircd_config).read()
+            contents = open(config.LIRC_DAEMON_CONF).read()
 
         except IOError:
             contents = ''
@@ -747,7 +749,7 @@ class BackendService(PolicyKitService):
             contents = None
 
         if contents:
-            open(lircd_config, 'w').write(contents)
+            open(config.LIRC_DAEMON_CONF, 'w').write(contents)
 
     @dbus.service.method(dbus_interface=INTERFACE_NAME,
                          in_signature='', out_signature='',
