@@ -333,12 +333,20 @@ class RemotesDatabase(object):
                             previous_remote.filename)
 
     def get(self, name, default=None):
-        '''
-        Looks up the remote matching name.
-        '''
+        '''Looks up the remote matching name.'''
 
         return self.__remotes.get(name, default)
 
+    def find(self, vendor, product, default=None):
+        '''Tries to find the specified remote control.'''
+
+        for remote in self:
+            if (remote.vendor == vendor and
+                remote.product == product):
+                return remote
+
+        return default
+
     def __iter__(self):
         return iter(self.__remotes.values())
     def __len__(self):
@@ -987,9 +995,29 @@ def find_remote_config():
     '''Finds the location our customized lircd.conf file.'''
 
     if has_include_keyword():
-        return os.path.join(config.LIRC_CONFDIR, 'lircd.conf.gnome'), True
+        return config.LIRC_REMOTE_CONF, True
 
-    return os.path.join(config.LIRC_CONFDIR, 'lircd.conf'), False
+    return config.LIRC_DAEMON_CONF, False
+
+def check_hardware_settings(selected_remote):
+    '''Check if the hardware settings are sane.'''
+
+    remote_config, can_include = find_remote_config()
+
+    if can_include and not re.search(
+        r'^\s*include\s+%s\s*$' % re.escape(config.LIRC_REMOTE_CONF),
+        open(config.LIRC_DAEMON_CONF).read(), re.MULTILINE):
+        return False
+
+    parser = RemotesParser()
+    parser.read(open(remote_config))
+
+    for remote in parser.remotes:
+        if (remote.vendor == selected_remote.vendor and
+            remote.product == selected_remote.product):
+            return True
+
+    return False
 
 if '__main__' == __name__:
     print find_remote_config()
